#!/bin/ksh
#

########################################################
# set paths and files

MODULE="ErcRANOS"
RELEASE="6.0.13.0.10"    
RP=$(echo $RELEASE|sed 's/\.//g')

SourceDir="${FLEXPM_HOME}/patches/${RELEASE}"
WorkDir=$SourceDir/workdir
TarDir=${SourceDir}/tarball/${MODULE}_${RP}_UI.tgz

### get ts
TS=`cat $SourceDir/Backup/.ts.txt`
BACKUP_DIR=$SourceDir/Backup/$TS

########################################################

# Check env settings
 echo "Checking environment....."

  if ! [[ -d ${FLEXPM_HOME} ]]; then
     echo "Env variable FLEXPM_HOME must be set to appropriate dir before installation."
     exit;
  fi

  if ! [[ -d ${FLEXPM_BASE} ]]; then
     echo "Env variable FLEXPM_BASE must be set to appropriate dir before installation."
     exit;
  fi

  if [ -z ${DB_CONNECT} ]; then
     echo "Env variable DB_CONNECT must be set to approriate database connection values."
     exit 1;
  fi

  ###### module variable validation
  if ! [[ -d ${ErcRANOS_HOME} ]]; then
     echo "Env variable ErcRANOS_HOME must be set to appropriate dir before installation."
     exit;
  fi

    #######################################################
    # Installing module...
    #######################################################

    date +"+ Installing Patch $MODULE $RELEASE at %T, %D ..."

    echo "+ Backing up original files and installing new files..."
    cd $FLEXPM_BASE
    mkdir -p ${BACKUP_DIR}

    ${WorkDir}/untar.pl $SourceDir $TarDir $FLEXPM_BASE $BACKUP_DIR

    ###### module installation customerize here...

    cd $PM_HOME/peik/xml
    touch parser.err
    chmod 777 parser.err

    echo "### running dict_update ###" 
    cd $ErcRANOS_HOME/peik
    make dict_update  ### dict_update will call to update jloader meta-data for any new/updated counters as well
    ret=$?

    if  [ $ret == 0 ] ; then
 
       echo "### completed dict_update ###"

       ### SEAde64824 : regen scenario query to cater active/complete scenario with new entities
       #echo "+ running regen_sce_query.sql..."
       #echo "@${WorkDir}/regen_sce_query.sql" | sqlplus -s ${DB_CONNECT}
       #echo " regen_sce_query.sql done."

       #recompile all invalid objects (except for views...):
       echo "+ recompiling invalid object(s)..."
       chmod u+x ${WorkDir}/recompile_schema.sh
       ${WorkDir}/recompile_schema.sh

       #and we recompile for invalid views here...
       echo "+ recompiling invalid view(s)..."
       chmod u+x ${WorkDir}/recompile_view.sh
       ${WorkDir}/recompile_view.sh
       echo " recompiled done."

       date +"+ $MODULE $RELEASE upgrade is completed at %T, %D"
       echo ""

    fi ### [ $ret == 0 ] ; then
