#!/bin/ksh
###################################################################
#     Copyright  2002 WatchMark Corp. All rights reserved        #
###################################################################



###################################################################
# 	Description
###################################################################

# Copies Oracle Setup files from cd-rom to target machine


###################################################################
# 	Build Numbers and Paths
###################################################################

bldnum="2.0";
relnum="2.0";
if [ "$bldnum" = "[% bldnum %]" ]
then
	bldnum="2.0";
fi 
if [ "$relnum" = "[% relnum %]" ]
then
	relnum="2.0";
fi 
oracle_dir="oracle_setup";

trap 'echo ; echo "** Interrupt **" ; exit ' 1 2 3 15


###################################################################
# 	Find dirname and basename
###################################################################

start_dir="`dirname $0`"
script_name="`basename $0`"
current_dir="`pwd`"


if [ "${start_dir}" != "." ]
then
	cd ${start_dir} 1>/dev/null || exit 1
	#print "Current directory is: ${current_dir}"
fi 


###################################################################
# 	Get Destination Path
###################################################################


print "\nWatchMark Prospect\n";

print "[% mfgname %] [% rel %] Server Preparation (bldnum ${bldnum})\n\n";


print "Please enter destination path for Oracle Setup files.";
print "NOTE: Since a reboot is required, please do not";
print "enter the /tmp filesystem. When entering the path,";
print "please use an absolute path.\n";
print -n "Destination path: ";
read dest_path;


echo "${dest_path}" | /bin/egrep "^\/tmp$|^\/tmp\/.*" 2>/dev/null;

# refuse tmp entry
if [ "$?" == "0" ]
then
	print "\n\nError: Cannot copy files to /tmp filesystem.";
	print "Please rerun script and select another destination path.";
	exit 1;
fi

echo "${dest_path}" | /bin/egrep -v "^\/.*" 2>/dev/null;

# refuse relative paths
if [ "$?" == "0" ]
then
	print "\n\nError: $0 script requires an absolute path.";
	print "Please rerun script and select an absolute destination path.";
	exit 1;
fi

# build path
dest_path="${dest_path}/${oracle_dir}/${relnum}";


print -n "\nCopy Oracle Setup files to: ${dest_path} (yes|no)? : ";
read answer;

echo "${answer}" | /bin/egrep -i "^yes$|^y$" 2>/dev/null;

# exit if no
if [ "$?" == "0" ]
then
	:
else
	print "Exiting...";
	exit 0;
fi


# must be directory and writable
if [ -d "${dest_path}" -a -w "${dest_path}" ]
then
	print "\nDestination path exists and is writeable.";
else

	print "\nCreating directory: ${dest_path}";
	/bin/mkdir -p -m 775 ${dest_path};

	if [ -d "${dest_path}" -a -w "${dest_path}" ]
	then
		print "\nDestination path exists and is writeable.";
	else
		print "\nError: Cannot create directory: ${dest_path}";
		exit 1;	
	fi

fi


###################################################################
# 	Copy Files
###################################################################


print "\nCopying files to ${dest_path}";

/bin/tar cpfv - . | ( cd ${dest_path} && /bin/tar -xpBf - );

print "\n\nPlease change directory to ${dest_path} and continue install.";

exit 0;




