-- # @(#) sw/oracle/monitor-sizes.sql = report space utilization
-- # @(#) monitor-files.sql ; 1.5.0 00/11/15 12:29:01

    set pagesize 200
    set linesize  80
    set feedback off

    column "File_Name"       format a32 trunc;
    column "File_Id"         format 9999;

    column "Tablespace Name" format a15 trunc;
    column "# Bytes"         format 9,999,999,999;
    column "# Used"          format 9,999,999,999;
    column "# Free"          format 9,999,999,999;
    column "% Free"          format 99.999;

    prompt
    prompt List of Tablespace Datafiles

    select 
	(b.tablespace_name)			"Tablespace Name",
	(b.file_id)				"File_Id"   ,
	(b.bytes)				"# Bytes"   ,
	(sum(nvl(a.bytes,0))/(b.bytes))*100	"% Free"    ,
	(b.file_name)				"File_Name"  
    from sys.dba_free_space a, sys.dba_data_files b
	where a.file_id(+) = b.file_id
	group by b.tablespace_name, b.file_id, b.bytes, b.file_name
	    order by b.tablespace_name;

    select 
	(b.tablespace_name)			"Tablespace Name",
	(b.file_id)				"File_Id"   ,
	(b.bytes)				"# Bytes"   ,
	(sum(nvl(a.bytes,0))/(b.bytes))*100	"% Free"    ,
	(sum(nvl(a.bytes,0))*1)			"# Free"    ,
	(b.bytes - sum(nvl(a.bytes,0)))		"# Used"     
    from sys.dba_free_space a, sys.dba_data_files b
	where a.file_id(+) = b.file_id
	group by b.tablespace_name, b.file_id, b.bytes, b.file_name
	    order by b.tablespace_name;

    prompt
    prompt Summary of Tablespace Utilization

    column tablespace_name format a15 trunc           heading "Tablespace Name";

    column datafile_size   format 99,999,999,999      heading "File Size";
    column file_name       format a32                 heading "File Name";

    column total_mb        format 9,999,999.999 trunc heading "Tablespace Size"
    column used_mb         format 9,999,999.999 trunc heading "MB Used"
    column free_mb         format 9,999,999.999 trunc heading "MB Free"
    column over_flag       format a6                  heading "< 10%"
    column pct_free        format 99.999              heading "% Free"

    break on report;

    compute sum label "TOTAL" of total_mb  on report;
    compute sum label "TOTAL" of used_mb   on report;
    compute sum label "TOTAL" of free_mb   on report;

    SELECT ts.tablespace_name            		tablespace_name ,
	   ts.ts_size/ (1024*1024)                   	total_mb ,
    decode(sign((free.ts_free/ts.ts_size)*100 - 10), 1,' ',' <**> ') over_flag ,
	   (free.ts_free/ts.ts_size)*100		pct_free ,
	   free.ts_free/(1024*1024)                 	free_mb  ,
	   (ts.ts_size - free.ts_free)/(1024*1024)     	used_mb   
    FROM 
    (   SELECT tablespace_name, sum(bytes) ts_size
	    FROM sys.dba_data_files
		GROUP BY tablespace_name
	) ts,
    (   SELECT df.tablespace_name, sum(nvl(fs.bytes, 0)) ts_free
	    FROM sys.dba_free_space fs, sys.dba_data_files df
		WHERE fs.file_id (+)= df.file_id
		    GROUP BY df.tablespace_name
	)   free
	    WHERE ts.tablespace_name = free.tablespace_name
		ORDER BY ts.tablespace_name;

    prompt

    exit;
