set lines 120
set feedback off
set serveroutput on size 1000000 format wrapped;
-- This "format wrapped" is to avoid trim leading space in dbms_output.put_line

DECLARE
   CURSOR Cur_Ent_Tab IS 
   SELECT wmn_entity.entity_id entID, wmn_entity.entity_name entName, 
   wmd_dict_table.table_name tabName
   FROM wmd_dict_table, wmn_entity 
   WHERE 
   ( wmn_entity.entity_id = wmd_dict_table.entity_id ) 
   AND 
   (wmd_dict_table.is_time_series = 'Y' AND wmd_dict_table.summary_id = 0 )
   ORDER BY entID, entName , tabName ;
   
   CURSOR topLevelEnt IS 
   SELECT distinct wmn_instance_context.fullkey FullKey, 
     wmn_Entity.Entity_Id  Ent_ID, 
     wmn_instance_context.Instance_Id Ins_ID,
	 wmn_Entity.Entity_Name Ent_Name, 
	 wmn_Entity.Entity_Table  Ent_Table,
	 wmn_Entity.EntityOrderNum Ent_Order_num
     FROM wmn_Entity,  wmn_instance_context
	 WHERE 
	  wmn_Entity.Entity_Id = wmn_instance_context.Entity_Id
	 AND
	  wmn_Entity.EntityOrderNum =1 ;
	  
-- Dynamic Cursor ...
   TYPE cur_typ IS REF CURSOR;
   cur          CUR_TYP;

   vStart_Date 	DATE := NULL;
   vEnd_Date 	DATE := NULL;
   sqlStmt 	VARCHAR2(1000) := '';
   vTableCount 	INTEGER :=0;
   vEntityCount INTEGER :=0;
   vSystemCount INTEGER :=0;
   vSystemID 	VARCHAR2(30) :=NULL;
   vTotal 	INTEGER :=0;
   
BEGIN

-- Build Summary Report  
   Dbms_Output.Put_Line (' ');
   Dbms_Output.Put_Line (' :: S U M M A R Y   R E P O R T :: ');
   Dbms_Output.Put_Line (' ');
   Dbms_Output.Put_Line ('	===========================================================================================================');
   Dbms_Output.Put_Line ('	  Entity Name              Table Name    			     First TSTAMP         Last TSTAMP    	') ;									
   Dbms_Output.Put_Line ('	===========================================================================================================');
   
   FOR ent IN Cur_Ent_Tab
   LOOP
         
 	sqlStmt := ' SELECT MIN(tstamp) , MAX(tstamp) ' ||   
	            ' FROM ' ||  ent.tabName ;
		 
  	EXECUTE IMMEDIATE sqlStmt INTO vStart_Date, vEnd_Date;
		 
        Dbms_OutPut.Put_Line ('            ' || rpad(ent.entName,23) || rpad(ent.tabName, 40) ||  Lpad (To_Char(vStart_Date,'YYYY-MM-DD HH24:MI'),16) || '     '  || Lpad (To_Char(vEnd_Date,'YYYY-MM-DD HH24:MI'),16) );
        Dbms_Output.Put_Line (' ');
          
   END LOOP;   -- Cur_Ent_Tab

-- Inititialize for next report
   sqlStmt := '';
   vStart_Date := NULL;
   vEnd_Date  := NULL;
   Dbms_Output.Put_Line ('	===========================================================================================================' );
-- End of Summary Report

   Dbms_Output.Put_Line (' ');
   Dbms_Output.Put_Line (' :: D E T A I L  R E P O R T :: ');
   Dbms_Output.Put_Line (' ');

-- Build Detail report for Traffic   
  Dbms_Output.Put_Line ('	=======================================================================================================');
  Dbms_Output.Put_Line ('	  System ID     Entity Name    		Table Name                               Distinct TSTAMP    	') ;									
  Dbms_Output.Put_Line ('	=======================================================================================================');

   FOR full IN topLevelEnt
   LOOP 
	vSystemID := full.FullKey;
      		
   		FOR ent IN Cur_Ent_Tab
   		LOOP
		    --Build dynamic cursor 
			-- Ignore table for pattern _EVT_%_RAW% ...
                       IF INSTR(ent.TabName,'_EVT_') = 0 AND INSTR(ent.TabName,'_RAW_') = 0 
                       THEN
			sqlStmt := ' SELECT DISTINCT tstamp FROM ' || ent.TabName || 
                                   ' WHERE SUBSTR(id,1,(INSTR(id,' || CHR(39) || '-' || CHR(39) || 
				   ') - 1) ) = ' || CHR(39) || vSystemID || CHR(39); 
			vStart_Date := NULL;
			OPEN cur FOR sqlStmt ;
			LOOP
			    FETCH cur into vStart_Date;
			    IF cur%NOTFOUND THEN
				EXIT;
			    END IF;
			    Dbms_OutPut.Put_Line ('	     ' || rpad(full.FullKey,10) || rpad(ent.entName,25) || 
				                  rpad(ent.tabName, 40) ||  
						  Lpad (To_Char(vStart_Date,'YYYY-MM-DD HH24:MI'),16) );
			     IF vStart_Date is NULL THEN
				vTableCount := 0;
                             ELSE 
				vTableCount := vTableCount + 1 ;
			     END IF;

			--   EXIT WHEN cur%NOTFOUND;
			END LOOP;
                        IF vTableCount > 0 THEN
		            Dbms_OutPut.Put_Line ('     ' || '                                           ' || ent.tabName || ' >> Sub Total= ' || to_char(vTableCount));
			END IF;
		        vSystemCount := vSystemCount + vTableCount ;
		        vTableCount := 0;
                        END IF;
   		END LOOP; -- End of Cur_Ent_Tab
        -- Print the sub total Count at System Level:
   		 Dbms_Output.Put_Line ('     ' || '       ======================================' );
		 Dbms_OutPut.Put_Line ('     ' || '         System ID: ' || full.FullKey || ' Traffic Total = ' || to_char(vSystemCount));
   		 Dbms_Output.Put_Line ('     ' || '       ======================================' );
		 vTotal := vTotal + vSystemCount;
		 vSystemCount := 0;
   END LOOP;
   Dbms_OutPut.Put_Line ('     ' || '     System Grand Total = ' || to_char(vTotal));
-- End of Detail for Traffic   
END;
/
exit
--
------------------------------------------------------------------------
--
-- Local Variables:
-- mode: pls
-- End:
